package com.ruoyi.ngtools.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.ngtools.domain.NgNgpar;
import com.ruoyi.ngtools.mapper.NgMeterparMapper;
import com.ruoyi.ngtools.domain.NgMeterpar;
import com.ruoyi.ngtools.service.INgMeterparService;

/**
 * 流量计参数Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-03
 */
@Service
public class NgMeterparServiceImpl implements INgMeterparService 
{
    @Autowired
    private NgMeterparMapper ngMeterparMapper;

    /**
     * 查询流量计参数
     * 
     * @param id 流量计参数主键
     * @return 流量计参数
     */
    @Override
    public NgMeterpar selectNgMeterparById(String id)
    {
        return ngMeterparMapper.selectNgMeterparById(id);
    }

    /**
     * 查询流量计参数列表
     * 
     * @param ngMeterpar 流量计参数
     * @return 流量计参数
     */
    @Override
    public List<NgMeterpar> selectNgMeterparList(NgMeterpar ngMeterpar)
    {
        return ngMeterparMapper.selectNgMeterparList(ngMeterpar);
    }

    /**
     * 新增流量计参数
     * 
     * @param ngMeterpar 流量计参数
     * @return 结果
     */
    @Transactional
    @Override
    public int insertNgMeterpar(NgMeterpar ngMeterpar)
    {
        ngMeterpar.setCreateTime(DateUtils.getNowDate());
        int rows = ngMeterparMapper.insertNgMeterpar(ngMeterpar);
        insertNgNgpar(ngMeterpar);
        return rows;
    }

    /**
     * 修改流量计参数
     * 
     * @param ngMeterpar 流量计参数
     * @return 结果
     */
    @Transactional
    @Override
    public int updateNgMeterpar(NgMeterpar ngMeterpar)
    {
        ngMeterpar.setUpdateTime(DateUtils.getNowDate());
        ngMeterparMapper.deleteNgNgparByMeterno(ngMeterpar.getId());
        insertNgNgpar(ngMeterpar);
        return ngMeterparMapper.updateNgMeterpar(ngMeterpar);
    }

    /**
     * 批量删除流量计参数
     * 
     * @param ids 需要删除的流量计参数主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteNgMeterparByIds(String[] ids)
    {
        ngMeterparMapper.deleteNgNgparByMeternos(ids);
        return ngMeterparMapper.deleteNgMeterparByIds(ids);
    }

    /**
     * 删除流量计参数信息
     * 
     * @param id 流量计参数主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteNgMeterparById(String id)
    {
        ngMeterparMapper.deleteNgNgparByMeterno(id);
        return ngMeterparMapper.deleteNgMeterparById(id);
    }

    /**
     * 新增天然气物性参数信息
     * 
     * @param ngMeterpar 流量计参数对象
     */
    public void insertNgNgpar(NgMeterpar ngMeterpar)
    {
        List<NgNgpar> ngNgparList = ngMeterpar.getNgNgparList();
        String id = ngMeterpar.getId();
        if (StringUtils.isNotNull(ngNgparList))
        {
            List<NgNgpar> list = new ArrayList<NgNgpar>();
            for (NgNgpar ngNgpar : ngNgparList)
            {
                ngNgpar.setMeterno(id);
                list.add(ngNgpar);
            }
            if (list.size() > 0)
            {
                ngMeterparMapper.batchNgNgpar(list);
            }
        }
    }
}
